==> aws-cdk.aws-lambda-1.29.0.tar.gz: package/lib/lambda-augmentations.generated.d.ts <==
import * as cloudwatch from '@aws-cdk/aws-cloudwatch';
declare module "./function-base" {
    interface IFunction {
        /**
         * Return the given named metric for this Function
         */
        metric(metricName: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How often this Lambda is throttled
         *
         * Sum over 5 minutes
         */
        metricThrottles(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How often this Lambda is invoked
         *
         * Sum over 5 minutes
         */
        metricInvocations(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How many invocations of this Lambda fail
         *
         * Sum over 5 minutes
         */
        metricErrors(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How long execution of this Lambda takes
         *
         * Average over 5 minutes
         */
        metricDuration(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    }
    interface FunctionBase {
        /**
         * Return the given named metric for this Function
         */
        metric(metricName: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How often this Lambda is throttled
         *
         * Sum over 5 minutes
         */
        metricThrottles(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How often this Lambda is invoked
         *
         * Sum over 5 minutes
         */
        metricInvocations(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How many invocations of this Lambda fail
         *
         * Sum over 5 minutes
         */
        metricErrors(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How long execution of this Lambda takes
         *
         * Average over 5 minutes
         */
        metricDuration(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    }
}

==> aws-cdk.aws-lambda-1.68.0.tar.gz: package/lib/lambda-augmentations.generated.d.ts <==
import * as cloudwatch from '@aws-cdk/aws-cloudwatch';
declare module "./function-base" {
    /**
     *
     */
    interface IFunction {
        /**
         * Return the given named metric for this Lambda Return the given named metric for this Function.
         */
        metric(metricName: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * Metric for the number of throttled invocations of this Lambda How often this Lambda is throttled.
         *
         * Sum over 5 minutes
         *
         * @default sum over 5 minutes
         */
        metricThrottles(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * Metric for the number of invocations of this Lambda How often this Lambda is invoked.
         *
         * Sum over 5 minutes
         *
         * @default sum over 5 minutes
         */
        metricInvocations(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How many invocations of this Lambda fail.
         *
         * Sum over 5 minutes
         */
        metricErrors(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * Metric for the Duration of this Lambda How long execution of this Lambda takes.
         *
         * Average over 5 minutes
         *
         * @default average over 5 minutes
         */
        metricDuration(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    }
    /**
     *
     */
    interface FunctionBase {
        /**
         * Return the given named metric for this Function.
         */
        metric(metricName: string, props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How often this Lambda is throttled.
         *
         * Sum over 5 minutes
         */
        metricThrottles(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How often this Lambda is invoked.
         *
         * Sum over 5 minutes
         */
        metricInvocations(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How many invocations of this Lambda fail.
         *
         * Sum over 5 minutes
         */
        metricErrors(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
        /**
         * How long execution of this Lambda takes.
         *
         * Average over 5 minutes
         */
        metricDuration(props?: cloudwatch.MetricOptions): cloudwatch.Metric;
    }
}
